import { NonNullablePaths } from '@wix/sdk-types';
export interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     * - `MANUAL`: Category is created manually by the user.
     * - `AUTO`: Category is created automatically.
     * - `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * - `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
export interface CategoryCounts {
    /** Total number of published events assigned to the category. Deleted events are excluded. */
    assignedEventsCount?: number | null;
    /** Total number of draft events assigned to the category. */
    assignedDraftEventsCount?: number | null;
}
export declare enum State {
    /** Created manually by the user. */
    MANUAL = "MANUAL",
    /** Created automatically. */
    AUTO = "AUTO",
    /** Created when publishing recurring events. */
    RECURRING_EVENT = "RECURRING_EVENT",
    /** Category is hidden. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
export type StateWithLiterals = State | 'MANUAL' | 'AUTO' | 'RECURRING_EVENT' | 'HIDDEN';
export interface CreateCategoryRequest {
    /** Category to create. */
    category: Category;
}
export interface CreateCategoryResponse {
    /** Created category. */
    category?: Category;
}
export interface BulkCreateCategoryRequest {
    /**
     * Categories to create.
     * @minSize 1
     * @maxSize 10
     */
    categories: Category[];
}
export interface BulkCreateCategoryResponse {
    /** Bulk create results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkCategoryResult {
    /** Metadata. */
    itemMetadata?: ItemMetadata;
    /** Created categories. */
    item?: Category;
}
export interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    _id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
export interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
export interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details due to exceeding the threshold for detailed failures. */
    undetailedFailures?: number;
}
export interface UpdateCategoryRequest {
    /** Category to update. */
    category: Category;
}
export interface UpdateCategoryResponse {
    /** Updated category. */
    category?: Category;
}
export interface DeleteCategoryRequest {
    /**
     * ID of category to be deleted.
     * @format GUID
     */
    categoryId: string;
}
export interface DeleteCategoryResponse {
}
export interface QueryCategoriesRequest {
    /** Options to use when querying categories. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more details. */
    query: QueryV2;
    /**
     * Predefined sets of fields to return.
     * - `COUNTS`: Returns `assignedEventsCount`.
     * @maxSize 1
     */
    fieldset?: CategoryFieldsetWithLiterals[];
}
export interface QueryV2 extends QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the form [{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]
     * See [supported fields](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events).
     * @maxSize 20
     */
    sort?: Sorting[];
}
/** @oneof */
export interface QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
}
export interface Sorting {
    /**
     * Name of the field to sort by
     * @maxLength 100
     */
    fieldName?: string;
    /** Sort order (ASC/DESC). Defaults to ASC */
    order?: SortOrderWithLiterals;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
export type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
export interface Paging {
    /**
     * Number of items to load per page.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
export declare enum CategoryFieldset {
    /** Include `assignedEventsCount` in the response. */
    COUNTS = "COUNTS"
}
/** @enumType */
export type CategoryFieldsetWithLiterals = CategoryFieldset | 'COUNTS';
export interface QueryCategoriesResponse {
    /** List of categories. */
    categories?: Category[];
    /** Metadata for the paginated results. */
    metaData?: PagingMetadataV2;
}
export interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
export interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
export interface AssignEventsRequest {
    /**
     * ID of category to which events should be assigned.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
export interface AssignEventsResponse {
}
export interface BulkAssignEventsRequest {
    /**
     * A list of category IDs to which events should be assigned.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId: string[];
}
export interface BulkAssignEventsResponse {
    /** Bulk assign results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkAssignEventsAsyncRequest {
    /**
     * Category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
export interface BulkAssignEventsAsyncResponse {
}
export interface UnassignEventsRequest {
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
export interface UnassignEventsResponse {
}
export interface BulkUnassignEventsRequest {
    /**
     * A list of category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId?: string[];
}
export interface BulkUnassignEventsResponse {
    /** Results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkUnassignEventsAsyncRequest {
    /**
     * Category ID.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
export interface BulkUnassignEventsAsyncResponse {
}
export interface ListEventCategoriesRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
}
export interface ListEventCategoriesResponse {
    /** A list of categories. */
    categories?: Category[];
}
export interface ReorderCategoryEventsRequest extends ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
}
/** @oneof */
export interface ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
export interface ReorderCategoryEventsResponse {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
export type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
type CategoryNonNullablePaths = `_id` | `name` | `states`;
/**
 * Creates a category.
 * @public
 * @requiredField category
 * @param category - Category to create.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @returns Created category.
 * @fqn wix.events.categories.CategoryManagement.CreateCategory
 */
export declare function createCategory(category: Category): Promise<NonNullablePaths<Category, CategoryNonNullablePaths>>;
/**
 * Creates multiple categories at once.
 * @param categories - Categories to create.
 * @public
 * @requiredField categories
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkCreateCategory
 */
export declare function bulkCreateCategory(categories: Category[]): Promise<NonNullablePaths<BulkCreateCategoryResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | {
    [P in CategoryNonNullablePaths]: `results.${number}.item.${P}`;
}[CategoryNonNullablePaths] | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`>>;
/**
 * Updates an existing category.
 * @param _id - Category ID.
 * @public
 * @requiredField _id
 * @requiredField category
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @returns Updated category.
 * @fqn wix.events.categories.CategoryManagement.UpdateCategory
 */
export declare function updateCategory(_id: string, category: UpdateCategory): Promise<NonNullablePaths<Category, CategoryNonNullablePaths>>;
export interface UpdateCategory {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     * - `MANUAL`: Category is created manually by the user.
     * - `AUTO`: Category is created automatically.
     * - `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * - `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
/**
 * Deletes a category.
 * @param categoryId - ID of category to be deleted.
 * @public
 * @requiredField categoryId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.DeleteCategory
 */
export declare function deleteCategory(categoryId: string): Promise<void>;
/**
 * Creates a query to retrieve a list of categories.
 *
 *
 * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
 *
 * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
 *
 * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
 *
 *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
 * @public
 * @param options - Options to use when querying categories.
 * @permissionScope Read Events - all read permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.READ-EVENTS
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Read Events
 * @permissionScopeId SCOPE.DC-EVENTS.READ-EVENTS
 * @permissionScope Manage Guest List
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-GUEST-LIST
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-EVENTS
 * @permissionId WIX_EVENTS.READ_CATEGORIES
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.events.categories.CategoryManagement.QueryCategories
 */
export declare function queryCategories(options?: QueryCategoriesOptions): CategoriesQueryBuilder;
export interface QueryCategoriesOptions {
    /**
     * Predefined sets of fields to return.
     * - `COUNTS`: Returns `assignedEventsCount`.
     * @maxSize 1
     */
    fieldset?: CategoryFieldsetWithLiterals[] | undefined;
}
interface QueryOffsetResult {
    currentPage: number | undefined;
    totalPages: number | undefined;
    totalCount: number | undefined;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
export interface CategoriesQueryResult extends QueryOffsetResult {
    items: Category[];
    query: CategoriesQueryBuilder;
    next: () => Promise<CategoriesQueryResult>;
    prev: () => Promise<CategoriesQueryResult>;
}
export interface CategoriesQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     */
    eq: (propertyName: '_id' | 'name', value: any) => CategoriesQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments. */
    ascending: (...propertyNames: Array<'_createdDate'>) => CategoriesQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments. */
    descending: (...propertyNames: Array<'_createdDate'>) => CategoriesQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object. */
    limit: (limit: number) => CategoriesQueryBuilder;
    /** @param skip - Number of items to skip in the query results before returning the results. */
    skip: (skip: number) => CategoriesQueryBuilder;
    find: () => Promise<CategoriesQueryResult>;
}
/**
 * Assigns events to a single category.
 * @param categoryId - ID of category to which events should be assigned.
 * @param eventId - A list of events IDs.
 * @public
 * @requiredField categoryId
 * @requiredField eventId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.AssignEvents
 */
export declare function assignEvents(categoryId: string, eventId: string[]): Promise<void>;
/**
 * Assigns events to multiple categories at once.
 * @param categoryId - A list of category IDs to which events should be assigned.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.eventId
 * @param options - Options to use when assigning events to multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkAssignEvents
 */
export declare function bulkAssignEvents(categoryId: string[], options: NonNullablePaths<BulkAssignEventsOptions, `eventId`>): Promise<NonNullablePaths<BulkAssignEventsResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | {
    [P in CategoryNonNullablePaths]: `results.${number}.item.${P}`;
}[CategoryNonNullablePaths] | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`>>;
export interface BulkAssignEventsOptions {
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId: string[];
}
/**
 * Assigns events that match given filter criteria to multiple categories.
 *
 * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 * @param categoryId - Category IDs.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.filter
 * @param options - Options to use when assigning events to multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkAssignEventsAsync
 */
export declare function bulkAssignEventsAsync(categoryId: string[], options: NonNullablePaths<BulkAssignEventsAsyncOptions, `filter`>): Promise<void>;
export interface BulkAssignEventsAsyncOptions {
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
/**
 * Unassigns events from a category.
 * @param categoryId - Category ID.
 * @param eventId - A list of events IDs.
 * @public
 * @requiredField categoryId
 * @requiredField eventId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.UnassignEvents
 */
export declare function unassignEvents(categoryId: string, eventId: string[]): Promise<void>;
/**
 * Unassigns events from multiple categories at once.
 * @param categoryId - A list of category IDs.
 * @public
 * @requiredField categoryId
 * @param options - Options to use when removing events from multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkUnassignEvents
 */
export declare function bulkUnassignEvents(categoryId: string[], options?: BulkUnassignEventsOptions): Promise<NonNullablePaths<BulkUnassignEventsResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | {
    [P in CategoryNonNullablePaths]: `results.${number}.item.${P}`;
}[CategoryNonNullablePaths] | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`>>;
export interface BulkUnassignEventsOptions {
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId?: string[];
}
/**
 * Removes events that match given filter criteria from multiple categories.
 *
 * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 * @param categoryId - Category ID.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.filter
 * @param options - Options to use when removing events from multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkUnassignEventsAsync
 */
export declare function bulkUnassignEventsAsync(categoryId: string[], options: NonNullablePaths<BulkUnassignEventsAsyncOptions, `filter`>): Promise<void>;
export interface BulkUnassignEventsAsyncOptions {
    /**
     * Criteria that must be met for an event to be considered for the bulk assign. Supported filters for this API:
     * - `_id`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     * - `name`: [`eq()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/eq)
     */
    filter: Record<string, any> | null;
}
/**
 * Retrieves a list of categories that are not in the `HIDDEN` state.
 * @param eventId - Event ID.
 * @public
 * @requiredField eventId
 * @permissionId WIX_EVENTS.READ_CATEGORIES
 * @permissionScope Read Events - all read permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.READ-EVENTS
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Read Events
 * @permissionScopeId SCOPE.DC-EVENTS.READ-EVENTS
 * @permissionScope Manage Guest List
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-GUEST-LIST
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.events.categories.CategoryManagement.ListEventCategories
 */
export declare function listEventCategories(eventId: string): Promise<NonNullablePaths<ListEventCategoriesResponse, {
    [P in CategoryNonNullablePaths]: `categories.${number}.${P}`;
}[CategoryNonNullablePaths]>>;
/**
 * Change the order of events that are assigned to the same category on the Events Widget.
 *
 *
 * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
 * @param categoryId - Category ID.
 * @public
 * @requiredField categoryId
 * @param options - Options to use when reordering events.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.ReorderCategoryEvents
 */
export declare function reorderCategoryEvents(categoryId: string, options?: ReorderCategoryEventsOptions): Promise<void>;
export interface ReorderCategoryEventsOptions extends ReorderCategoryEventsOptionsReferenceEventOneOf {
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
/** @oneof */
export interface ReorderCategoryEventsOptionsReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
export {};
