import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { queryBuilder } from '@wix/sdk-runtime/query-builder';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixEventsV1Category from './events-v1-category-categories.http.js';
// @ts-ignore
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
export var State;
(function (State) {
    /** Created manually by the user. */
    State["MANUAL"] = "MANUAL";
    /** Created automatically. */
    State["AUTO"] = "AUTO";
    /** Created when publishing recurring events. */
    State["RECURRING_EVENT"] = "RECURRING_EVENT";
    /** Category is hidden. */
    State["HIDDEN"] = "HIDDEN";
})(State || (State = {}));
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
export var CategoryFieldset;
(function (CategoryFieldset) {
    /** Include `assignedEventsCount` in the response. */
    CategoryFieldset["COUNTS"] = "COUNTS";
})(CategoryFieldset || (CategoryFieldset = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Creates a category.
 * @public
 * @requiredField category
 * @param category - Category to create.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @returns Created category.
 * @fqn wix.events.categories.CategoryManagement.CreateCategory
 */
export async function createCategory(category) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ category: category });
    const reqOpts = ambassadorWixEventsV1Category.createCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.category;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { category: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['category']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Creates multiple categories at once.
 * @param categories - Categories to create.
 * @public
 * @requiredField categories
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkCreateCategory
 */
export async function bulkCreateCategory(categories) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categories: categories,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkCreateCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categories: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['categories']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Updates an existing category.
 * @param _id - Category ID.
 * @public
 * @requiredField _id
 * @requiredField category
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @returns Updated category.
 * @fqn wix.events.categories.CategoryManagement.UpdateCategory
 */
export async function updateCategory(_id, category) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        category: { ...category, id: _id },
    });
    const reqOpts = ambassadorWixEventsV1Category.updateCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.category;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: { category: '$[1]' },
            explicitPathsToArguments: { 'category.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'category']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Deletes a category.
 * @param categoryId - ID of category to be deleted.
 * @public
 * @requiredField categoryId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.DeleteCategory
 */
export async function deleteCategory(categoryId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
    });
    const reqOpts = ambassadorWixEventsV1Category.deleteCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['categoryId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Creates a query to retrieve a list of categories.
 *
 *
 * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
 *
 * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
 *
 * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
 *
 *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
 * @public
 * @param options - Options to use when querying categories.
 * @permissionScope Read Events - all read permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.READ-EVENTS
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Read Events
 * @permissionScopeId SCOPE.DC-EVENTS.READ-EVENTS
 * @permissionScope Manage Guest List
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-GUEST-LIST
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-EVENTS
 * @permissionId WIX_EVENTS.READ_CATEGORIES
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.events.categories.CategoryManagement.QueryCategories
 */
export function queryCategories(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    return queryBuilder({
        func: async (payload) => {
            const reqOpts = ambassadorWixEventsV1Category.queryCategories({
                ...payload,
                ...(options ?? {}),
            });
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, options];
            return renameKeysFromSDKRequestToRESTRequest({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data }) => {
            const transformedData = renameKeysFromRESTResponseToSDKResponse(transformPaths(data, []));
            return {
                items: transformedData?.categories,
                pagingMetadata: transformedData?.metaData,
            };
        },
        errorTransformer: (err) => {
            const transformedError = sdkTransformError(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
/**
 * Assigns events to a single category.
 * @param categoryId - ID of category to which events should be assigned.
 * @param eventId - A list of events IDs.
 * @public
 * @requiredField categoryId
 * @requiredField eventId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.AssignEvents
 */
export async function assignEvents(categoryId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.assignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Assigns events to multiple categories at once.
 * @param categoryId - A list of category IDs to which events should be assigned.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.eventId
 * @param options - Options to use when assigning events to multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkAssignEvents
 */
export async function bulkAssignEvents(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        eventId: options?.eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkAssignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                eventId: '$[1].eventId',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Assigns events that match given filter criteria to multiple categories.
 *
 * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 * @param categoryId - Category IDs.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.filter
 * @param options - Options to use when assigning events to multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkAssignEventsAsync
 */
export async function bulkAssignEventsAsync(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        filter: options?.filter,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkAssignEventsAsync(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', filter: '$[1].filter' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Unassigns events from a category.
 * @param categoryId - Category ID.
 * @param eventId - A list of events IDs.
 * @public
 * @requiredField categoryId
 * @requiredField eventId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.UnassignEvents
 */
export async function unassignEvents(categoryId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.unassignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Unassigns events from multiple categories at once.
 * @param categoryId - A list of category IDs.
 * @public
 * @requiredField categoryId
 * @param options - Options to use when removing events from multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkUnassignEvents
 */
export async function bulkUnassignEvents(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        eventId: options?.eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkUnassignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                eventId: '$[1].eventId',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Removes events that match given filter criteria from multiple categories.
 *
 * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 * @param categoryId - Category ID.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.filter
 * @param options - Options to use when removing events from multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkUnassignEventsAsync
 */
export async function bulkUnassignEventsAsync(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        filter: options?.filter,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkUnassignEventsAsync(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', filter: '$[1].filter' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a list of categories that are not in the `HIDDEN` state.
 * @param eventId - Event ID.
 * @public
 * @requiredField eventId
 * @permissionId WIX_EVENTS.READ_CATEGORIES
 * @permissionScope Read Events - all read permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.READ-EVENTS
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Read Events
 * @permissionScopeId SCOPE.DC-EVENTS.READ-EVENTS
 * @permissionScope Manage Guest List
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-GUEST-LIST
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.events.categories.CategoryManagement.ListEventCategories
 */
export async function listEventCategories(eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ eventId: eventId });
    const reqOpts = ambassadorWixEventsV1Category.listEventCategories(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { eventId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Change the order of events that are assigned to the same category on the Events Widget.
 *
 *
 * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
 * @param categoryId - Category ID.
 * @public
 * @requiredField categoryId
 * @param options - Options to use when reordering events.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.ReorderCategoryEvents
 */
export async function reorderCategoryEvents(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        categoryId: categoryId,
        eventId: options?.eventId,
        beforeEventId: options?.beforeEventId,
        afterEventId: options?.afterEventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.reorderCategoryEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                eventId: '$[1].eventId',
                beforeEventId: '$[1].beforeEventId',
                afterEventId: '$[1].afterEventId',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=events-v1-category-categories.universal.js.map