export interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     *
     * `MANUAL`: Category is created manually by the user.
     * `AUTO`: Category is created automatically.
     * `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission scope is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
export interface CategoryCounts {
    /** Total number of draft events assigned to the category. */
    assignedEventsCount?: number | null;
    /** Total number of published events assigned to the category. Deleted events are excluded. */
    assignedDraftEventsCount?: number | null;
}
export declare enum State {
    /** Created manually by the user. */
    MANUAL = "MANUAL",
    /** Created automatically. */
    AUTO = "AUTO",
    /** Created when publishing recurring events. */
    RECURRING_EVENT = "RECURRING_EVENT",
    /** Category is hidden. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
export type StateWithLiterals = State | 'MANUAL' | 'AUTO' | 'RECURRING_EVENT' | 'HIDDEN';
export interface CreateCategoryRequest {
    /** Category to create. */
    category: Category;
}
export interface CreateCategoryResponse {
    /** Created category. */
    category?: Category;
}
export interface BulkCreateCategoryRequest {
    /**
     * Categories to create.
     * @minSize 1
     * @maxSize 10
     */
    categories: Category[];
}
export interface BulkCreateCategoryResponse {
    /** Bulk create results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkCategoryResult {
    /** Metadata. */
    itemMetadata?: ItemMetadata;
    /** Category. */
    item?: Category;
}
export interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
export interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
export interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
export interface UpdateCategoryRequest {
    /** Category to update. */
    category: Category;
}
export interface UpdateCategoryResponse {
    /** Updated category. */
    category?: Category;
}
export interface DeleteCategoryRequest {
    /**
     * ID of category to be deleted.
     * @format GUID
     */
    categoryId: string;
}
export interface DeleteCategoryResponse {
}
export interface QueryCategoriesRequest {
    /** Options to use when querying categories. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more details. */
    query: QueryV2;
    /**
     * Predefined sets of fields to return.
     * - `COUNTS`: Returns `assignedEventsCount`.
     * @maxSize 1
     */
    fieldset?: CategoryFieldsetWithLiterals[];
}
export interface QueryV2 extends QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the form [{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]
     * See [supported fields](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events).
     * @maxSize 20
     */
    sort?: Sorting[];
}
/** @oneof */
export interface QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
}
export interface Sorting {
    /**
     * Name of the field to sort by
     * @maxLength 100
     */
    fieldName?: string;
    /** Sort order (ASC/DESC). Defaults to ASC */
    order?: SortOrderWithLiterals;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
export type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
export interface Paging {
    /**
     * Number of items to load per page.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
export declare enum CategoryFieldset {
    /** Include `assignedEventsCount` in the response. */
    COUNTS = "COUNTS"
}
/** @enumType */
export type CategoryFieldsetWithLiterals = CategoryFieldset | 'COUNTS';
export interface QueryCategoriesResponse {
    /** List of categories. */
    categories?: Category[];
    /** Metadata for the paginated results. */
    metaData?: PagingMetadataV2;
}
export interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
export interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
export interface AssignEventsRequest {
    /**
     * ID of category to which events should be assigned.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
export interface AssignEventsResponse {
}
export interface BulkAssignEventsRequest {
    /**
     * A list of category IDs to which events should be assigned.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId: string[];
}
export interface BulkAssignEventsResponse {
    /** Bulk assign results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkAssignEventsAsyncRequest {
    /**
     * Category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter: Record<string, any> | null;
}
export interface BulkAssignEventsAsyncResponse {
}
export interface UnassignEventsRequest {
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
export interface UnassignEventsResponse {
}
export interface BulkUnassignEventsRequest {
    /**
     * A list of category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId?: string[];
}
export interface BulkUnassignEventsResponse {
    /** Results. */
    results?: BulkCategoryResult[];
    /** Metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkUnassignEventsAsyncRequest {
    /**
     * Category ID.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter: Record<string, any> | null;
}
export interface BulkUnassignEventsAsyncResponse {
}
export interface ListEventCategoriesRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
}
export interface ListEventCategoriesResponse {
    /** A list of categories. */
    categories?: Category[];
}
export interface ReorderCategoryEventsRequest extends ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
}
/** @oneof */
export interface ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
export interface ReorderCategoryEventsResponse {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entityAsJson?: string;
    /** Indicates the event was triggered by a restore-from-trashbin operation for a previously deleted entity */
    restoreInfo?: RestoreInfo;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntityAsJson?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntityAsJson?: string | null;
}
export interface ActionEvent {
    bodyAsJson?: string;
}
export interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
export type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
